{% comment %}
This snippet allows customizing the theme (css file) as defined per user in the UserPreference model theme field.
Include this snippet within the head tags of your base template:
<head>{% include 'snippits/user_theme.htm' %}</head>
{% endcomment %}

{% get_theme request as user_theme %}
{% if user_theme %}
<link href="{% static user_theme.css_file %}" rel="stylesheet">
{% else %}
<link href="{% static 'default.css' %}" rel="stylesheet">
{% endif %}
