<table class="table table-condensed table-bordered table-striped" data-toggle="table" data-search="true"
       data-flat="true" data-pagination="true" data-show-pagination-switch="true" data-show-columns="true"
       data-show-export="true" data-reorderable-columns="true" data-resizable="false" data-export-types="['excel','csv','txt','sql']">
    <thead>
        <tr>
            <th data-field="url" data-sortable="true">URL</th>
            <th data-field="created_at" data-sortable="true">Last Visited</th>
            <th>Actions</th>
        </tr>
    </thead>
    <tbody>
    {% for row in queryset %}
        <tr>
            <td><a href="{{ row.url }}">{{ row.url }}</a></td>
            <td>{{ row.updated_at }}</td>

            <!-- actions -->
            <td>
                <a href="#" onClick="confirmAction('{% url "userextensions:delete_recent" row.pk %}', 'Delete Recent', 'This recent will be permanently removed from your list of recents; do you wish to continue?', 'Continue', 'POST');">
                    <i class="fas fa-trash ml-1 mr-1"></i>
                </a>
            </td>
        </tr>
    {% endfor %}
    </tbody>
</table>
